==> zio-aws-apigatewayv2_3-5.17.104.4-sources.jar: zio/aws/apigatewayv2/model/GetModelTemplateRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetModelTemplateRequest(apiId: __string, modelId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest = {
    import GetModelTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .modelId(__string.unwrap(modelId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelTemplateRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelTemplateRequest.wrap(buildAwsValue())
}
object GetModelTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelTemplateRequest =
      zio.aws.apigatewayv2.model.GetModelTemplateRequest(apiId, modelId)
    def apiId: __string
    def modelId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getModelId: ZIO[Any, Nothing, __string] = ZIO.succeed(modelId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
  ) extends zio.aws.apigatewayv2.model.GetModelTemplateRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val modelId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.modelId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
  ): zio.aws.apigatewayv2.model.GetModelTemplateRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-5.17.295.18-sources.jar: zio/aws/apigatewayv2/model/GetModelTemplateRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetModelTemplateRequest(apiId: __string, modelId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest = {
    import GetModelTemplateRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .modelId(modelId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetModelTemplateRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetModelTemplateRequest.wrap(buildAwsValue())
}
object GetModelTemplateRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetModelTemplateRequest =
      zio.aws.apigatewayv2.model.GetModelTemplateRequest(apiId, modelId)
    def apiId: __string
    def modelId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getModelId: ZIO[Any, Nothing, __string] = ZIO.succeed(modelId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
  ) extends zio.aws.apigatewayv2.model.GetModelTemplateRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val modelId: __string = impl.modelId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetModelTemplateRequest
  ): zio.aws.apigatewayv2.model.GetModelTemplateRequest.ReadOnly = new Wrapper(
    impl
  )
}
